/* $Workfile: Dsp54Def.h $   $Revision: 6 $    $Modtime: 9/23/04 3:33p $  */
#ifndef DSP54_DEF_H
#define DSP54_DEF_H
/*******************************************************************************

  @doc PublicDspSdkApi Dsp54Def

  Odin TeleSystems Inc.

  SAA-1007-1 OTX DSP C54x Software Development Kit (SDK)

  Macro, Constant, and type definitions for the DSP C54x SDK API

  @module
  Dsp54Def | Constants, Macros, and Types for the DSP C54x SDK

  @contents2
  Dsp54Def.h |

  @index enum struct type | Dsp54Def

  @contents2
  DSP SDK Constants, Macros, and Types (Dsp54Def.h) |

  @head3 DSP C54x SDK Macro, Constant, and Type Reference |

  @index enum struct type | Dsp54Def


*******************************************************************************/

/*******************************************************************************
  MACROS
*******************************************************************************/

#if defined(CHIP_54CST) || defined(CHIP_5410A) || defined(CHIP_5416)
#define MCBSP_SUPPORT 1
#endif

/* @type IN | Just used to specify direction of a function parameter */
#define IN
/* @type OUT | Just used to specify direction of a function parameter */
#define OUT

/* @type OTXDSP_TRUE | Boolean value TRUE */
#define OTXDSP_TRUE        1
/* @type OTXDSP_FALSE | Boolean value TRUE */
#define OTXDSP_FALSE       0

/* Companding Law Type */
/* @type OTXDSP_ULAW | U-Law Companding */
#define OTXDSP_ULAW       0
/* @type OTXDSP_ALAW | A-Law Companding */
#define OTXDSP_ALAW       1

/* @type OTXDSP_INVALID_HANDLE | Invalid Logical Device Handle Value */
#define OTXDSP_INVALID_HANDLE 0xFFFF

/* @type OTXDSP_NO_TASKREF | No Task Reference */
#define OTXDSP_NO_TASKREF  0xFFFF


/* @type OTXDSP_BSP_TXBUF_ADDR | The starting address of the Transmit buffer    */
/* The buffer for the Buffered Serial Port can only be placed at a certain      */
/* memory region of the C54x memory map. Place the TX buffer at an absolute         */
/* address within this region.                                                      */
/* Note that this macro needs to be defined as a command line */
/* parameter to the compiler. */

/* @type OTXDSP_BSP_RXBUF_ADDR | The starting address of the Receive buffer     */
/* The buffer for the Buffered Serial Port can only be placed at a certain      */
/* memory region of the C54x memory map. Place the RX buffer at an absolute         */
/* address within this region.                                                      */
/* Note that this macro needs to be defined as a command line */
/* parameter to the compiler. */


/* @type OTXDSP_BSP_TXBUF_SIZE | The size of the Transmit buffer for the highest    */
/* highway speed that the DSP program supports. */
/* Interrupt are generated when */
/* the buffer is full and half-full.  */
/* Note that that the size is in Words (16-bits), i.e. in multiple of two           */
/* timeslots. */
/* The processing task for the transmitter should write to the autobuffer */
/* before he hands if off to the the DMA controller or the */
/* buffered serial port for transmission. */
/* Note that this macro needs to be defined as a command line */
/* parameter to the compiler. */

/* @type OTXDSP_BSP_RXBUF_SIZE | The size of the Receive buffer for the highest */
/* highway speed that the DSP program supports. */
/* Interrupt are generated when */
/* the buffer is full and half-full. */
/* Note that that the size is in Words (16-bits), i.e. in multiple of two */
/* timeslots.  */
/* Note that this macro needs to be defined as a command line */
/* parameter to the compiler. */

/* @type OTXDSP_HWY_SPEEDS | Supported highway speeds for this DSP program. */
/* The DSP connects to other devices via a serial port, which can be considered */
/* as a TDM highway. This macro defines the highway speeds that the DSP code supports. */
/* The macro is a bit pattern where bit0=2048kpbs, bit1=4096kpbs, and bit2=8192kpbs.  */
/* Setting any of these three bits to 1 specifies that this highway speed is supported */
/* by this DSP program. If this macro is not defined on the command line, it is set to */
/* 0x0001 (2048kpbs) in the Dsp54Api.c code. */

/* @type OTXDSP_HWY_SPEED_2M | Highway speed 2048 kpbs is supported for this DSP program. */
#define OTXDSP_HWY_SPEED_2M 0x0001

/* @type OTXDSP_HWY_SPEED_4M | Highway speed 4096 kpbs is supported for this DSP program. */
#define OTXDSP_HWY_SPEED_4M 0x0002

/* @type OTXDSP_HWY_SPEED_8M | Highway speed 8192 kpbs is supported for this DSP program. */
#define OTXDSP_HWY_SPEED_8M 0x0004


/* Commonly used assembly operations */
/* @type C54X_SET_XF_BIT | Macro for setting the XF bit. Connected to the heart-beat LED */
#define C54X_SET_XF_BIT         asm("\t ssbx    XF")

/* @type C54X_CLR_XF_BIT | Macro for clearing the XF bit. Connected to the heart-beat LED */
#define C54X_CLR_XF_BIT         asm("\t rsbx    XF")

/* @type C54X_SET_INT_MASK_BIT | Macro for globally disable interrupts. */
#define C54X_SET_INT_MASK_BIT   asm("\t ssbx    INTM")

/* @type C54X_CLR_INT_MASK_BIT | Macro for globally enable interrupts. */
#define C54X_CLR_INT_MASK_BIT   asm("\t rsbx    INTM")

/* @type C54X_WAIT_FOR_INT | Macro for entering idle state until an interrupt occurs. */
#define C54X_WAIT_FOR_INT       asm("\t idle    1")

/* @type C54X_NOP | Macro for No-operation */
#define C54X_NOP                asm("\t nop")

/* @type C54X_IFR_HPIINT | Interrupt Flag Register, Host Port Interrupt Flag */
#define C54X_IFR_HPINT 0x0200
/* @type C54X_IFR_INT3 | Interrupt Flag Register, Flag for External Interrupt 3 */
#define C54X_IFR_INT3  0x0100
/* @type C54X_IFR_TXINT | Interrupt Flag Register, Flag for Serial Port Transmit Interrupt */
#define C54X_IFR_TXINT 0x0080
/* @type C54X_IFR_TRINT | Interrupt Flag Register, Flag for Serial Port Receive Interrupt */
#define C54X_IFR_TRINT 0x0040
/* @type C54X_IFR_BXINT | Interrupt Flag Register, Flag for Buffered Serial Port Transmit Interrupt */
#define C54X_IFR_BXINT 0x0020
/* @type C54X_IFR_BRINT | Interrupt Flag Register, Flag for Buffered Serial Port Receive Interrupt */
#define C54X_IFR_BRINT 0x0010
/* @type C54X_IFR_TINT | Interrupt Flag Register, Flag for Timer Interrupt */
#define C54X_IFR_TINT  0x0008
/* @type C54X_IFR_INT2 | Interrupt Flag Register, Flag for External Interrupt 2 */
#define C54X_IFR_INT2  0x0004
/* @type C54X_IFR_INT1 | Interrupt Flag Register, Flag for External Interrupt 1 */
#define C54X_IFR_INT1  0x0002
/* @type C54X_IFR_INT0 | Interrupt Flag Register, Flag for External Interrupt 0 */
#define C54X_IFR_INT0  0x0001

/* @type C54X_ST1_FRCT | Bit in Status Register 1 (ST1) that determines whether or not the */
/* multiplier output is left shifted by one */
#define C54X_ST1_FRCT  0x0040

#define C54X_HINTMASK  0x0A      /* 0Ah=HINT bit and SMOD bit */
#define C54X_HINTBIT   0x08      /* 08h=HINT bit */



/*******************************************************************************
  TYPES
*******************************************************************************/
struct OtxDspHpiEventBufDiag {
  unsigned short cwFreeBuffer;    // @field Current number of free words in the HPI Event Buffer
  unsigned short cwMinFreeBuffer; // @field Minimum number of free words in the HPI Event Buffer since the application started
  unsigned short coLostEvents;    // @field Number of lost event packets (due to a full buffer) since the application started
};

// @type OtxDspHpiDiag | Struct for diagnostics of the HPI Event buffer (events passed from the DSP to the host)
typedef struct OtxDspHpiEventBufDiag OtxDspHpiEventBufDiag;

struct OtxDspTimeStamp {
  unsigned short nHighPart;  // Bit 48-63
  unsigned short nMidPart;   // Bit 32-47
  unsigned short nLowPart;   // Bit 16-31
};

// @type OtxDspTimeStamp | Struct used for passing a 64 bit timestamp for each HPI Event
typedef struct OtxDspTimeStamp OtxDspTimeStamp;

// @type OtxDspIsrCallbackFnP | Callback function pointer for the ISRs defined in Otx54Api.c
typedef void  (*OtxDspIsrCallbackFnP) (void);


/*******************************************************************************
  GLOBAL VARIABLES
*******************************************************************************/

extern OtxDspIsrCallbackFnP g_pFnTimerIsr;
extern OtxDspIsrCallbackFnP g_pFnRxSerialPortIsr;
extern OtxDspIsrCallbackFnP g_pFnTxSerialPortIsr;
extern OtxDspIsrCallbackFnP g_pFnHostPortIsr;

extern unsigned short g_nHighwaySpeed;
extern unsigned short g_nTimeslotsPerFrame;
extern unsigned short g_nWordslotsPerFrame;

extern OtxDspHpiEventBufDiag g_hpiEventBufDiag;

extern OtxDspTimeStamp g_timeStamp;

extern volatile short g_bGotRxSerialPortInterrupt;
extern volatile short g_bGotTxSerialPortInterrupt;
extern volatile short g_bGotHostPortInterrupt;

extern volatile short g_bRxSerialPortHalf;
extern volatile short g_bTxSerialPortHalf;

extern volatile unsigned short g_nFrameBufferCounter;
extern volatile unsigned short g_nTimerCounter;

/*--------------------------------------------------------------------------*\
  CERTAIN USEFUL MEMORY MAPPED REGISTERS
\*--------------------------------------------------------------------------*/
/* @type C54X_IMR_REG | Interrupt Mask Register  */
extern volatile unsigned short * const C54X_IMR_REG;
/* @type C54X_IFR_REG | Interrupt Flag Register  */
extern volatile unsigned short * const C54X_IFR_REG;
/* @type C54X_ST0_REG | Status Register 0 */
extern volatile unsigned short * const C54X_ST0_REG;
/* @type C54X_ST1_REG | Status Register 1 */
extern volatile unsigned short * const C54X_ST1_REG;
/* @type C54X_PMST_REG | Processor Mode Status Register */
extern volatile unsigned short * const C54X_PMST_REG;
/* @type C54X_BDRR_REG | Buffered Serial Port (BSP) Data Receive Register */
extern volatile unsigned short * const C54X_BDRR_REG;
/* @type C54X_BDXR_REG | Buffered Serial Port (BSP) Data Transmit Register */
extern volatile unsigned short * const C54X_BDXR_REG;
/* @type C54X_SPC0_REG | Serial Port Control Register 0 */
extern volatile unsigned short * const C54X_SPC0_REG;
extern volatile unsigned short * const C54X_TIM_REG;
/* @type C54X_PRD_REG | Timer Period Register */
extern volatile unsigned short * const C54X_PRD_REG;
/* @type C54X_TCR_REG | Timer Control Register */
extern volatile unsigned short * const C54X_TCR_REG;
/* @type C54X_TRCV_REG | TDM Data Receive Register */
extern volatile unsigned short * const C54X_TRCV_REG;
/* @type C54X_TDXV_REG | TDM Data Transmit Register */
extern volatile unsigned short * const C54X_TDXR_REG;
/* @type C54X_SPC1_REG | Serial Port Control Register 1 */
extern volatile unsigned short * const C54X_SPC1_REG;
/* @type C54X_SWWSR_REG | Software Wait State Register */
extern volatile unsigned short * const C54X_SWWSR_REG;
extern volatile unsigned short * const C54X_BSCR_REG;
/* @type C54X_HPIC_REG | HPI Control Register */
extern volatile unsigned short * const C54X_HPIC_REG;
extern volatile unsigned short * const C54X_BSPCE_REG;
/* @type C54X_AXR_REG | ABU Address Transmit Register */
extern volatile unsigned short * const C54X_AXR_REG;
/* @type C54X_BKX_REG | ABU Transmit Buffer Size Register */
extern volatile unsigned short * const C54X_BKX_REG;
/* @type C54X_ARR_REG | ABU Address Receive Register */
extern volatile unsigned short * const C54X_ARR_REG;
/* @type C54X_BKR_REG | ABU Receive Buffer Size Register */
extern volatile unsigned short * const C54X_BKR_REG;
/* @type C54X_CLKM_REG | Clock Mode Register */
extern volatile unsigned short * const C54X_CLKMD_REG;

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999-2004


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif /* DSP54_DEF_H */
